summaryrefslogtreecommitdiff
path: root/sources/scalac/symtab/EntryTags.java
diff options
context:
space:
mode:
authorMartin Odersky <odersky@gmail.com>2003-10-30 14:59:42 +0000
committerMartin Odersky <odersky@gmail.com>2003-10-30 14:59:42 +0000
commitd23d0a9c737c6350b3f00a555a3ec61fff8d92dc (patch)
tree7c6a3649edf42fceb39087c97eeae9f760a8503f /sources/scalac/symtab/EntryTags.java
parent4764fc555502237fc7f423af4200520a975a69fd (diff)
downloadscala-d23d0a9c737c6350b3f00a555a3ec61fff8d92dc.tar.gz
scala-d23d0a9c737c6350b3f00a555a3ec61fff8d92dc.tar.bz2
scala-d23d0a9c737c6350b3f00a555a3ec61fff8d92dc.zip
*** empty log message ***
Diffstat (limited to 'sources/scalac/symtab/EntryTags.java')
-rw-r--r--sources/scalac/symtab/EntryTags.java75
1 files changed, 40 insertions, 35 deletions
diff --git a/sources/scalac/symtab/EntryTags.java b/sources/scalac/symtab/EntryTags.java
index 71df3f73ff..ade0cb60bd 100644
--- a/sources/scalac/symtab/EntryTags.java
+++ b/sources/scalac/symtab/EntryTags.java
@@ -15,24 +15,27 @@ public interface EntryTags {
* Symtab = nentries_Nat {Entry}
* Entry = 1 TERMNAME len_Nat NameInfo
* | 2 TYPENAME len_Nat NameInfo
* | 3 NONEsym len_Nat
* | 4 TYPEsym len_Nat SymbolInfo lobound_Ref
* | 5 ALIASsym len_Nat SymbolInfo constrsym_Ref
* | 6 CLASSsym len_Nat SymbolInfo thistype_Ref constrsym_Ref
* | 7 VALsym len_Nat SymbolInfo [classsym_Ref]
* | 8 EXTref len_Nat name_Ref [owner_Ref]
* | 9 EXTMODCLASSref len_Nat name_Ref [owner_Ref]
* | 10 NOtpe len_Nat
* | 11 THIStpe len_Nat sym_Ref
* | 12 SINGLEtpe len_Nat type_Ref sym_Ref
* | 13 TYPEREFtpe len_Nat type_Ref sym_Ref {targ_Ref}
* | 14 COMPOUNDtpe len_Nat classsym_Ref {tpe_Ref}
* | 15 METHODtpe len_Nat tpe_Ref {tpe_Ref}
* | 16 POLYTtpe len_Nat tpe_Ref {sym_Ref}
* | 17 OVERLOADEDtpe len_Nat {sym_Ref} {tpe_Ref}
* | 20 FLAGGEDtpe len_Nat flags_Nat tpe_Ref
* SymbolInfo = name_Ref owner_Ref flags_Nat info_Ref
* NameInfo = <character sequence of length len_Nat in Utf8 format>
+ * NumInfo = <len_Nat-byte signed number in big endian format>
* Ref = Nat
*
* len is remaining length after `len'.
@@ -40,25 +43,27 @@ public interface EntryTags {
int TERMname = 1,
TYPEname = 2,
- NONEsym = 3,
- TYPEsym = 4,
- ALIASsym = 5,
- CLASSsym = 6,
- VALsym = 7,
- EXTref = 8,
- EXTMODCLASSref = 9,
- NOtpe = 10,
- THIStpe = 11,
- SINGLEtpe = 12,
- TYPEREFtpe = 13,
- COMPOUNDtpe = 14,
- METHODtpe = 15,
- POLYtpe = 16,
- OVERLOADEDtpe = 17,
- UNBOXEDtpe = 18,
- UNBOXEDARRAYtpe = 19,
- FLAGGEDtpe = 20,
- ERRORtpe = 21;
+ NUMBER = 3,
+ NONEsym = 4,
+ TYPEsym = 5,
+ ALIASsym = 6,
+ CLASSsym = 7,
+ VALsym = 8,
+ EXTref = 9,
+ EXTMODCLASSref = 10,
+ NOtpe = 11,
+ THIStpe = 12,
+ SINGLEtpe = 13,
+ CONSTANTtpe = 14,
+ TYPEREFtpe = 15,
+ COMPOUNDtpe = 16,
+ METHODtpe = 17,
+ POLYtpe = 18,
+ OVERLOADEDtpe = 19,
+ UNBOXEDtpe = 20,
+ UNBOXEDARRAYtpe = 21,
+ FLAGGEDtpe = 22,
+ ERRORtpe = 23;
int firstSymTag = NONEsym, lastSymTag = VALsym;
int firstTypeTag = NOtpe, lastTypeTag = FLAGGEDtpe;
@@ -15,24 +15,27 @@ public interface EntryTags {
* Entry = 1 TERMNAME len_Nat NameInfo
* | 2 TYPENAME len_Nat NameInfo
- * | 3 NONEsym len_Nat
- * | 4 TYPEsym len_Nat SymbolInfo lobound_Ref
- * | 5 ALIASsym len_Nat SymbolInfo constrsym_Ref
- * | 6 CLASSsym len_Nat SymbolInfo thistype_Ref constrsym_Ref
- * | 7 VALsym len_Nat SymbolInfo [classsym_Ref]
- * | 8 EXTref len_Nat name_Ref [owner_Ref]
- * | 9 EXTMODCLASSref len_Nat name_Ref [owner_Ref]
- * | 10 NOtpe len_Nat
- * | 11 THIStpe len_Nat sym_Ref
- * | 12 SINGLEtpe len_Nat type_Ref sym_Ref
- * | 13 TYPEREFtpe len_Nat type_Ref sym_Ref {targ_Ref}
- * | 14 COMPOUNDtpe len_Nat classsym_Ref {tpe_Ref}
- * | 15 METHODtpe len_Nat tpe_Ref {tpe_Ref}
- * | 16 POLYTtpe len_Nat tpe_Ref {sym_Ref}
- * | 17 OVERLOADEDtpe len_Nat {sym_Ref} {tpe_Ref}
- * | 20 FLAGGEDtpe len_Nat flags_Nat tpe_Ref
+ * | 3 NUMBER lenNat NumInfo
+ * | 4 NONEsym len_Nat
+ * | 5 TYPEsym len_Nat SymbolInfo lobound_Ref
+ * | 6 ALIASsym len_Nat SymbolInfo constrsym_Ref
+ * | 7 CLASSsym len_Nat SymbolInfo thistype_Ref constrsym_Ref
+ * | 8 VALsym len_Nat SymbolInfo [classsym_Ref]
+ * | 9 EXTref len_Nat name_Ref [owner_Ref]
+ * | 10 EXTMODCLASSref len_Nat name_Ref [owner_Ref]
+ * | 11 NOtpe len_Nat
+ * | 12 THIStpe len_Nat sym_Ref
+ * | 13 SINGLEtpe len_Nat type_Ref sym_Ref
+ * | 14 CONSTANTtpe len_Nat type_Ref value_Ref
+ * | 15 TYPEREFtpe len_Nat type_Ref sym_Ref {targ_Ref}
+ * | 16 COMPOUNDtpe len_Nat classsym_Ref {tpe_Ref}
+ * | 17 METHODtpe len_Nat tpe_Ref {tpe_Ref}
+ * | 18 POLYTtpe len_Nat tpe_Ref {sym_Ref}
+ * | 19 OVERLOADEDtpe len_Nat {sym_Ref} {tpe_Ref}
+ * | 22 FLAGGEDtpe len_Nat flags_Nat tpe_Ref
* SymbolInfo = name_Ref owner_Ref flags_Nat info_Ref
* NameInfo = <character sequence of length len_Nat in Utf8 format>